﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Telerik.Windows.Controls.ChartView;
using Telerik.Charting;

namespace wpf_ChartView_588587
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            var data = this.GetData();
            this.BindChart(data);
        }

        private void BindChart(List<PlotInfo> data)
        {
            this.cartesianChart1.Series.Clear();

            var barTemplate1 = this.Resources["barTemplate1"] as DataTemplate;
            this.AddSeriesToChart(data, barTemplate1);

            var barTemplate2 = this.Resources["barTemplate2"] as DataTemplate;
            this.AddSeriesToChart(data, barTemplate2);
        }

        private void AddSeriesToChart(List<PlotInfo> data, DataTemplate barTemplate)
        {
            foreach (var plotInfo in data)
            {
                BarSeries barSeries = new BarSeries() 
                { 
                    CombineMode = ChartSeriesCombineMode.Stack, 
                    StackGroupKey = plotInfo.Date,
                    PointTemplate = barTemplate,
                };
                barSeries.DataPoints.Add(new CategoricalDataPoint() 
                {
                    Category = new DateTime(plotInfo.Date.Year, plotInfo.Date.Month, 1),
                    Value = plotInfo.YVal,
                });
                this.cartesianChart1.Series.Add(barSeries);
            }
        }

        private List<PlotInfo> GetData()
        {
            var data = new List<PlotInfo>() 
            {
                new PlotInfo { Date = new DateTime(2012, 9, 16), YVal = 27, },
                new PlotInfo { Date = new DateTime(2012, 9, 23), YVal = 15, },
                new PlotInfo { Date = new DateTime(2012, 9, 30), YVal = 16, },

                new PlotInfo { Date = new DateTime(2012, 10, 7), YVal = 22, },
                new PlotInfo { Date = new DateTime(2012, 10, 14), YVal = 20, },
                new PlotInfo { Date = new DateTime(2012, 10, 21), YVal = 11, },
                new PlotInfo { Date = new DateTime(2012, 10, 22), YVal = 20, },
                new PlotInfo { Date = new DateTime(2012, 10, 29), YVal = 21, },

                new PlotInfo { Date = new DateTime(2012, 11, 4), YVal = 22, },
                new PlotInfo { Date = new DateTime(2012, 11, 11), YVal = 20, },
                new PlotInfo { Date = new DateTime(2012, 11, 18), YVal = 11, },
                new PlotInfo { Date = new DateTime(2012, 11, 25), YVal = 20, },
            };
            
            return data;
        }
    }

    public class PlotInfo
    {
        public DateTime Date { get; set; }
        public double YVal { get; set; }
    }
}
